/**
 * Copyright (C) 2010  BonitaSoft S.A.
 * BonitaSoft, 31 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.rest.interceptor;

import java.util.List;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.Provider;

import org.jboss.resteasy.annotations.interception.ClientInterceptor;
import org.jboss.resteasy.client.ClientRequest;
import org.jboss.resteasy.client.ClientResponse;
import org.jboss.resteasy.spi.interception.ClientExecutionContext;
import org.jboss.resteasy.spi.interception.ClientExecutionInterceptor;
import org.ow2.bonita.facade.APIAccessor;
import org.ow2.bonita.facade.rest.stringconverter.MapStringConverter;
import org.ow2.bonita.util.Base64;


/**
 * @author Elias Ricken de Medeiros
 *
 */
@ClientInterceptor
@Provider
public class RESTClientExecutionInterceptor implements
    ClientExecutionInterceptor {

  private static Logger LOG = Logger.getLogger(RESTClientExecutionInterceptor.class.getName());
  private final static String AUTHENTICATION_SCHEME = "Basic";
  private final static String OPTIONS_PROPERTY_NAME = "options";  
  private final static String AUTHORIZATION_PROPERTY = "Authorization";
  
  @SuppressWarnings({ "unchecked", "rawtypes" })
  public ClientResponse execute(ClientExecutionContext ctx) throws Exception {
    ClientRequest request = ctx.getRequest();
    MultivaluedMap<String, String> formParameters = request.getFormParameters();
    List<String> options = null;
    //options in the a form parameter
    if (formParameters != null) {
      options = formParameters.get(OPTIONS_PROPERTY_NAME);
    }
    
    //options on the header
    if (options == null || options.isEmpty()){
      MultivaluedMap<String, String> headers = request.getHeaders();
      options = headers.get(OPTIONS_PROPERTY_NAME);
    }
    
    if ((options == null || options.isEmpty()) && LOG.isLoggable(Level.SEVERE)) {
      LOG.severe("No options map was found!");
      return ctx.proceed();
    }
    
    if (options.size() > 1 && LOG.isLoggable(Level.SEVERE)) {
      LOG.severe("More then one parameter named options was found!");
    }
    
    MapStringConverter converter = new MapStringConverter();
    
    Map<String, String> optionsMap = (Map<String, String>) converter.fromString(options.get(0));
    String userName = optionsMap.get(APIAccessor.REST_USER_OPTION);
    if (userName != null && !userName.trim().equals("")) {
      String passWord = optionsMap.get(APIAccessor.PASSWORD_HASH_OPTION);
      String encodedUserAndPswd = Base64.encodeBytes((userName + ":" + passWord).getBytes());
      request.getHeaders().add(AUTHORIZATION_PROPERTY, AUTHENTICATION_SCHEME + " " + encodedUserAndPswd);
    }
    
    return ctx.proceed();
  }

}
